@@ -1,9 +1,11 @@
 import json
 import shutil
 import time
+from collections import defaultdict
 from pathlib import Path
 
 import cv2 as cv
+from fiftyone import ViewField as F
 from tqdm import tqdm
 
 
@@ -18,13 +20,13 @@ def from_coco_instance(out_dir, dataset, class_names, field_name="segmentations"
     (out_dir / "data").mkdir(parents=True, exist_ok=False)
 
     if class_names is not None:
-        class_names = set(class_names)
+        dataset = dataset.filter_labels(field_name, F("label").is_in(class_names))
 
     if prefix is None:
         prefix = time.strftime(r"%y%m%d_%H%M%S")
 
     _db = {}
-    index = 0
+    counts = defaultdict(int)
     for sample in tqdm(dataset):
         img = cv.imread(sample.filepath, 1)
 
@@ -40,9 +42,6 @@ def from_coco_instance(out_dir, dataset, class_names, field_name="segmentations"
         for obj in detections:
             label = obj.label
 
-            if class_names is not None and label not in class_names:
-                continue
-
             _box = obj.bounding_box  # [x, y, w, h] / s
             x, y = round(_box[0] * img_w), round(_box[1] * img_h)
 
@@ -55,11 +54,13 @@ def from_coco_instance(out_dir, dataset, class_names, field_name="segmentations"
             if retval == 2:
                 continue
 
-            index += 1
             patch_mask = mask[:h, :w]
             patch = img[y:y + h, x:x + w]
 
-            file_stem = f"{prefix}_{index:06d}"
+            counts[label] += 1
+            _index = counts[label]
+            _label = "_".join(label.split())
+            file_stem = f"{prefix}_{_label}_{_index:06d}"
             patch_file = f"data/{label}/{file_stem}.jpg"
             mask_file = f"data/{label}/{file_stem}.png"
 
